#include <fstream>
#include <cassert>
#include <iostream>
#include <queue>
#include <vector>

using namespace std;
using Graph = vector<vector<int>>;

int n;

int find_root(vector<int>& degree, int l, int r) {
  for (int i = l; i < r; ++i)
    if (degree[i] == 1)
      return i;
}

void dfs(int node, Graph& graph, vector<bool>& used, int col, Graph& newGraph) {
  used[node] = true;
  for (auto other : graph[node])
    if (!used[other]) {
      if (col == 0) {
        newGraph[node].push_back(other);
        newGraph[other].push_back(node);
      }
      dfs(other, graph, used, !col, newGraph);
    }
}

bool check(int node, Graph& graph, vector<bool>& used, vector<int>& ans, int last_color) {
  int color;
  used[node] = true;
  ans.push_back(node);
  for (auto other : graph[node]) {
    if (other < n && node < n)
      color = 0;
    else if (other >= n && node >= n)
      color = 1;
    else color = 2;
    
    if (!used[other]) {
      if (color == last_color)
        return false;
      return check(other, graph, used, ans, color);
    }
  }
  return true;
}

int main() {
  ifstream cin("12-dungeon.in");
  ofstream cout("dungeon.out");
 
  int t, a, b;
  cin >> t;
  while(t--) {
    cin >> n;
    Graph graph(2 * n, vector<int>());
    vector<int> degree(2 * n);

    // Read white edges
    for (int i = 0; i < n - 1; ++i) {
      cin >> a >> b;
      --a; --b;
      graph[a].push_back(b);
      graph[b].push_back(a);
      ++degree[a];
      ++degree[b];
    }

    // Read black edges
    for (int i = 0; i < n - 1; ++i) {
      cin >> a >> b;
      --a; --b;
      graph[a].push_back(b);
      graph[b].push_back(a);
      ++degree[a];
      ++degree[b];
    }

    if (n % 2) {
      cout << "-1";
      continue;
    }

    vector<bool> used(2 * n, false);
    int root_white = find_root(degree, 0, n);
    int root_black = find_root(degree, n, 2 * n);
    Graph hton(2 * n);

    dfs(root_white, graph, used, 0, hton);
    dfs(root_black, graph, used, 0, hton);

    fill(used.begin(), used.end(), false);

    // Read red edges
    for (int i = 0; i < n; ++i) {
      cin >> a >> b;
      --a; --b;
      hton[a].push_back(b);
      hton[b].push_back(a);
    }
    
    bool ok = true;
    for (int i = 0; i < 2 * n && ok; ++i)
      if (hton[i].size() != 2) {
        ok = false;
      }
    if (ok == false) {
      cout << "-1\n";
      continue;
    }

    int other = -1;
    if (hton[0][0] >= n)
      other = hton[0][0];
    if (hton[0][1] >= n)
      other = hton[0][1];
    if (other == -1) {
      cout << "-1\n";
      continue;
    }

    used[0] = true;
    vector<int> ans;
    ans.push_back(0);
    ok = check(other, hton, used, ans, 2);
    if (ok == false || ans.size() != 2 * n)
      cout << "-1\n";
    else  {
      for (auto x : ans)
          cout << x + 1 << " ";
      cout << "\n";
    }
  }

  return 0;
}
